package com.nisum.paymentvendorsimulator.creditcard.services;

import com.nisum.paymentvendorsimulator.creditcard.domain.dto.*;
import com.nisum.paymentvendorsimulator.creditcard.data.DataServiceClient;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import java.io.IOException;

@Service
public class CreditCardService {

  private static final Logger logger = LoggerFactory.getLogger(CreditCardService.class);
  private final DataServiceClient dataClient;

  public CreditCardService(DataServiceClient dataClient) {
      this.dataClient = dataClient;
  }

  public CreditCardResponse authorize(CreditCardRequest ccRequest) {
    logger.info(String.valueOf(ccRequest));
    CreditCardResponse res = new CreditCardResponse();
    res.setCardNumber(ccRequest.getCard().getNumber());
    res.setCvv(ccRequest.getCard().getCvc());
    res.setId("123456789");

    CreditCardAddress ccAddress = ccRequest.getBillingAddress();
    res.setBillingAddress(ccAddress);

    res.setAmount(ccRequest.getAmount().getValue());

    CreditCardAuthorizeResponse ccAR = new CreditCardAuthorizeResponse();
    CreditCardAdditionalData additionalData = new CreditCardAdditionalData();

    additionalData.setExpiryDate(ccRequest.getCard().getExpiryMonth() + "/" + ccRequest.getCard().getExpiryYear());
    ccAR.setAdditionalData(additionalData);
    ccAR.setPspReference("123");

    res.setCreditCardAuthorizeResponse(ccAR);

    try {
        dataClient.saveAuthorization(res);
    } catch (IOException e) {
        System.out.println(e);
    }
    return res;
  }
}
